"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var child_process = require("child_process");
var path = require("path");
var util = require("util");
var configuration_1 = require("./configuration");
var Lint = /** @class */ (function () {
    function Lint() {
        this.NAME = "tslint";
        this.execSync = util.promisify(child_process.exec);
    }
    Lint.prototype.check = function (options, items) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var args;
            return tslib_1.__generator(this, function (_a) {
                args = [this.generateLintPaths(items).join(" ")];
                if (args[0].length === 0) {
                    return [2 /*return*/, Promise.resolve({
                            stdout: "",
                            stderr: ""
                        })];
                }
                args.push("-p " + (options.project !== undefined ? options.project : configuration_1.PROJECT_NAME));
                args.push("-c " + (options.config !== undefined ? options.config : configuration_1.CONFIG_NAME));
                return [2 /*return*/, this.execSync(this.NAME + " " + args.join(" "))];
            });
        });
    };
    Lint.prototype.generateLintPaths = function (items) {
        return items.reduce(function (acc, cur) {
            var curpath = cur.slice(2);
            var ext = path.extname(curpath);
            if (ext.length > 0 && ext !== ".ts") {
                return acc;
            }
            if (ext.length === 0) {
                curpath = "" + curpath + path.sep + "**";
            }
            acc.push(curpath);
            return acc;
        }, []);
    };
    return Lint;
}());
exports.Lint = Lint;
